@@ -20,7 +20,7 @@ our (
     $LEVEL_NAME_REGEX,
 );
 
-$VERSION = "0.94";
+$VERSION = "0.95";
 
 use Params::Validate qw(
     validate
@@ -291,7 +291,6 @@ sub enchunk {
         my $n_chunks = scalar @chunks;
         die 'Message too big' if $n_chunks > 128;
 
-        my $magic          = pack('C*', 0x1e,0x0f); # Chunked GELF magic
         my $message_id     = pack('L*', irand(),irand());
         my $sequence_count = pack('C*', $n_chunks);
 
@@ -299,7 +298,7 @@ sub enchunk {
         my $sequence_number = 0;
         foreach my $chunk (@chunks) {
            push @chunks_w_header,
-              $magic
+              $GELF_MSG_MAGIC
               . $message_id
               . pack('C*',$sequence_number++)
               . $sequence_count
@@ -460,14 +459,17 @@ Log::GELF::Util - Utility functions for Graylog's GELF format.
 
     sub process_chunks {
 
-        my @chunks;
+        my @accumulator;
         my $msg;
 
         do {
-            $msg = dechunk(\@chunks, decode_chunk(shift()));
+            $msg = dechunk(
+                \@accumulator,
+                decode_chunk(shift())
+            );
         } until ($msg);
 
-        return uncompress( $msg );
+        return uncompress($msg);
     };
 
     my $hr = validate_message( short_message => 'message' );
@@ -509,7 +511,7 @@ Timestamp, defaults to time() from L<Time::HiRes>.
 
 =item level
 
-Integer, equal to the standard C<syslog> levels, default is 1 (ALERT).
+Integer, equal to the standard syslog levels, default is 1 (ALERT).
 
 =item facility
 
@@ -534,15 +536,15 @@ disallowed.
 
 =head2 encode( \% )
 
-Accepts HASHREF to a structure representing a GELF message. The message
-will be converted validated with C<validate_message>.
+Accepts a HASHREF representing a GELF message. The message will be
+validated with L</validate_message>.
 
 Returns a JSON encoded string representing the message.
 
 =head2 decode( $ )
 
 Accepts a JSON encoded string representing the message. This will be
-converted to a hashref and validated with C<validate_message>.
+converted to a hashref and validated with L</validate_message>.
 
 Returns a HASHREF representing the validated message with any defaulted
 values added to the data structure.
@@ -568,8 +570,8 @@ Accepts an encoded message (JSON string) and chunks it according to the
 GELF chunking protocol.
 
 The optional second parameter is the maximum size of the chunks to produce,
-this must be a positive integer or the special strings C<'lan'> or C<'wan'>,
-see L</parse_size>. Defaults to 'wan'. A zero chunk size means no chunking
+this must be a positive integer or the special strings C<lan> or C<wan>,
+see L</parse_size>. Defaults to C<wan>. A zero chunk size means no chunking
 will be applied.
 
 If the message size is greater than the maximum size then an array of
@@ -593,14 +595,17 @@ Here is an example usage:
 
     sub process_chunks {
 
-        my @chunks;
+        my @accumulator;
         my $msg;
 
         do {
-            $msg = dechunk(\@chunks, decode_chunk(shift()));
+            $msg = dechunk(
+                \@accumulator,
+                decode_chunk(shift())
+            );
         } until ($msg);
 
-        return $msg;
+        return uncompress($msg);
     };
 
 =head2 is_chunked( $ )
@@ -610,31 +615,29 @@ Accepts a string and returns a true value if it is a GELF message chunk.
 =head2 decode_chunk( $ )
 
 Accepts a GELF message chunk and returns an ARRAYREF representing the
-chunk. The message consists of the following keys:
+unpacked chunk. Dies if the input is not a GELF chunk.
+
+The message consists of the following keys:
 
  id
  sequence_number
  sequence_count
  data
 
-C<decode_chunk> dies if the input is not a GELF chunk.
-
 =head2 parse_level( $ )
 
 Accepts a C<syslog> style level in the form of a number (1-7) or a string
 being one of C<emerg>, C<alert>, C<crit>, C<err>, C<warn>, C<notice>,
-C<info>, or C<debug>.
+C<info>, or C<debug>. Dies upon invalid input.
 
 The string forms may also be elongated and will still be accepted. For
 example C<err> and C<error> are equivalent.
 
-The associated C<syslog> level is returned in numeric form.
-
-L</parse_level> dies upon invalid input.
+The associated syslog level is returned in numeric form.
 
 =head2 parse_size( $ )
 
-Accepts integer specifying the chunk size or the special string values
+Accepts an integer specifying the chunk size or the special string values
 C<lan> or C<wan> corresponding to 8154 or 1420 respectively. An explanation
 of these values is in the code.
 
